pub struct SectionRevs {
pub task: i64,
pub todos: i64,
pub scraps: i64,
pub links: i64,
pub repos: i64,
pub worktrees: i64,
}Expand description
Revision numbers for each section, used for change detection.
Each section has a revision number that is incremented whenever data in that section is modified. This allows efficient change detection without complex queries.
Fields
task: i64Task metadata (description, ticket, alias) revision
todos: i64TODOs section revision
scraps: i64Scraps section revision
links: i64Links section revision
repos: i64Repositories section revision
worktrees: i64Worktrees section revision