Business logic services for the track CLI application.
This module contains services that implement the core business logic for managing tasks, TODOs, repositories, worktrees, links, and scraps. Each service encapsulates operations related to its domain and interacts with the database layer.
Re-exports
pub use link_service::LinkService;pub use link_service::ScrapService;pub use repo_service::RepoService;pub use task_service::TaskService;pub use todo_service::TodoService;pub use worktree_service::is_legacy_worktree;pub use worktree_service::LegacyWorktreeCleanupOutcome;pub use worktree_service::WorktreeService;
Modules
- agent_
context - git_
worktree - jj_task
- jj-task workspace map integration (reads
~/.config/jj/task-workspaces.json). - link_
service - repo_
service - task_
service - todo_
service - worktree_
service