Functions
- base_
repo_ has_ changes - Returns true when the base repo has changes outside
.worktrees/<slug>/. - branch_
exists - create_
git_ worktree - Create a git worktree and branch for a task slug.
- git_
branch_ name - Git branch name for a task slug.
- git_
worktree_ exists - git_
worktree_ path - Expected git worktree path (
.worktrees/<slug>/). - is_
git_ repository - repo_
has_ uncommitted_ changes