Module use_cases

Module use_cases 

Application use cases that coordinate domain services and external systems.

Use cases own multi-step workflows and transaction boundaries where a single service method is not enough.

Re-exports

pub use apply_todo_action::ApplyTodoActionUseCase;
pub use archive_task::ArchiveTaskOutcome;
pub use archive_task::ArchiveTaskUseCase;
pub use archive_task::DirtyWorkspace;
pub use complete_todo::CompleteTodoOutcome;
pub use complete_todo::CompleteTodoUseCase;
pub use create_today_task::CreateTodayTaskUseCase;
pub use sync_task::RepoSyncOutcome;
pub use sync_task::SyncTaskOutcome;
pub use sync_task::SyncTaskUseCase;
pub use sync_task::WorkspaceCreateError;
pub use sync_task::WorkspaceCreated;

Modules

apply_todo_action
archive_task
complete_todo
create_today_task
sync_task