Module services

Module services 

Business logic services for the track CLI application.

This module contains services that implement the core business logic for managing tasks, TODOs, repositories, worktrees, links, and scraps. Each service encapsulates operations related to its domain and interacts with the database layer.

Re-exports

pub use link_service::LinkService;
pub use link_service::ScrapService;
pub use repo_service::RepoService;
pub use task_service::TaskService;
pub use todo_service::TodoService;
pub use worktree_service::WorktreeService;

Modules

agent_context
git_worktree
jj_task
link_service
repo_service
task_service
todo_service
worktree_service