Module git_worktree

Module git_worktree 

Functions

base_repo_has_changes
Returns true when the base repo has changes outside .worktrees/<slug>/.
branch_exists
create_git_worktree
Create a git worktree and branch for a task slug.
git_branch_name
Git branch name for a task slug.
git_worktree_exists
git_worktree_path
Expected git worktree path (.worktrees/<slug>/).
is_git_repository
repo_has_uncommitted_changes