Module jj_task

Module jj_task 

Functions

expected_workspace_path
Default workspace path following agent-skill-jj layout (before jj-task start).
repo_key
Normalizes a git remote URL to owner/repo (same logic as jj-task.sh).
slug_registered
Returns true when jj-task has registered the slug for any of the given repo paths.
task_phase
Returns jj-task phase for a slug in the first matching repo, if any.
workspace_path
Returns the jj-task workspace path for a slug in a repo, if registered.