pub trait Trackable<C, S>where
C: TrackableMarker,
S: SerializationStrategy,{
// Required method
fn track<'notifier, I: Identifier>(
&mut self,
sender: &'notifier Sender<ModificationEvent<I>>,
identifier: I,
) -> Tracker<'_, 'notifier, C, S, I>;
}Expand description
A trait with functions for tracking struct value modifications.
Do not implement this trait manually but use the track attribute for less boiler plate code.
Required Methods
fn track<'notifier, I: Identifier>( &mut self, sender: &'notifier Sender<ModificationEvent<I>>, identifier: I, ) -> Tracker<'_, 'notifier, C, S, I>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.